==> feathers-mongoose-casl-dashboard-1.1.14.tgz: package/es/UserAbilities.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import { Button } from 'antd';
import { Formik } from 'formik';
import { docHelpers } from 'redux-admin'; //  'src/components/redux-admin';
import { NetProvider } from 'net-provider'; // 'src/components/net-provider';
import JSONPretty from 'react-json-pretty';

var index = function (_Component) {
  _inherits(index, _Component);

  function index(props) {
    _classCallCheck(this, index);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.renderForm = function (_ref) {
      var crudActions = _ref.crudActions;

      return React.createElement(
        Formik,
        {
          validate: function validate(values) {
            var errors = {};
            if (!values.serviceName || !values.serviceName.length) {
              errors.serviceName = 'Required';
            }
            return errors;
          },
          onSubmit: function onSubmit(values, _ref2) {
            var setSubmitting = _ref2.setSubmitting;

            setSubmitting(true);
            crudActions.Refresh({
              url: 'user-abilities',
              params: values,
              customHandleResponse: function customHandleResponse(res) {
                return res.data;
              },
              onEnd: function onEnd() {
                return setSubmitting(false);
              },
              onFailed: function onFailed() {
                return setSubmitting(false);
              }
            });
          }
        },
        function (_ref3) {
          var isValid = _ref3.isValid,
              resetForm = _ref3.resetForm,
              touched = _ref3.touched,
              values = _ref3.values,
              errors = _ref3.errors,
              handleSubmit = _ref3.handleSubmit,
              isSubmitting = _ref3.isSubmitting;

          return React.createElement(
            'form',
            { onSubmit: handleSubmit },
            docHelpers.getDocField({
              key: 'serviceName',
              label: 'Service Name',
              type: 'string'
            }),
            docHelpers.getDocField({
              referenceKey: 'users-abilities-ref',
              key: 'userId',
              label: 'User Id',
              type: 'string',
              ref: 'users',
              optionLabel: 'email',
              getParamsByValue: function getParamsByValue() {}
            }),
            docHelpers.getDocField({
              key: 'userId',
              label: 'User Id',
              type: 'string'
            }),
            React.createElement(
              Button,
              { htmlType: 'submit', disabled: isSubmitting || !isValid },
              'SEND'
            )
          );
        }
      );
    };

    _this.state = {};
    return _this;
  }

  index.prototype.renderResults = function renderResults(data) {
    return data && data.data && data.data.result ? React.createElement(
      'div',
      null,
      React.createElement(
        'h2',
        null,
        'Result'
      ),
      React.createElement(JSONPretty, { id: 'json-pretty', data: data.data.result })
    ) : '';
  };

  index.prototype.render = function render() {
    var _this2 = this;

    return React.createElement(
      NetProvider,
      {
        targetKey: 'user-abilities-check',
        clearOnUnMount: true
      },
      function (_ref4) {
        var data = _ref4.data,
            error = _ref4.error,
            crudActions = _ref4.crudActions;

        return React.createElement(
          'div',
          { className: 'userAbilities__wrapper' },
          React.createElement(
            'div',
            { className: 'userAbilities__form' },
            _this2.renderForm({ crudActions: crudActions })
          ),
          React.createElement(
            'div',
            { className: 'userAbilities__results' },
            error && React.createElement(
              'div',
              null,
              error
            ),
            _this2.renderResults({ data: data })
          )
        );
      }
    );
  };

  return index;
}(Component);

export default index;

==> feathers-mongoose-casl-dashboard-1.2.2.tgz: package/es/UserAbilities.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import { Button } from 'antd';
import { Formik } from 'formik';
import { docHelpers } from 'redux-admin'; //  ''redux-admin'';
import { NetProvider } from 'net-provider'; // 'src/components/net-provider';
import JSONPretty from 'react-json-pretty';

var index = function (_Component) {
  _inherits(index, _Component);

  function index(props) {
    _classCallCheck(this, index);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.renderForm = function (_ref) {
      var crudActions = _ref.crudActions;

      return React.createElement(
        Formik,
        {
          validate: function validate(values) {
            var errors = {};
            if (!values.serviceName || !values.serviceName.length) {
              errors.serviceName = 'Required';
            }
            return errors;
          },
          onSubmit: function onSubmit(values, _ref2) {
            var setSubmitting = _ref2.setSubmitting;

            setSubmitting(true);
            crudActions.Refresh({
              url: 'user-abilities',
              params: values,
              customHandleResponse: function customHandleResponse(res) {
                return res.data;
              },
              onEnd: function onEnd() {
                return setSubmitting(false);
              },
              onFailed: function onFailed() {
                return setSubmitting(false);
              }
            });
          }
        },
        function (_ref3) {
          var isValid = _ref3.isValid,
              resetForm = _ref3.resetForm,
              touched = _ref3.touched,
              values = _ref3.values,
              errors = _ref3.errors,
              handleSubmit = _ref3.handleSubmit,
              isSubmitting = _ref3.isSubmitting;

          return React.createElement(
            'form',
            { onSubmit: handleSubmit },
            docHelpers.getDocField({
              key: 'serviceName',
              label: 'Service Name',
              type: 'string'
            }),
            docHelpers.getDocField({
              referenceKey: 'users-abilities-ref',
              key: 'userId',
              label: 'User Id',
              type: 'string',
              ref: 'users',
              optionLabel: 'email',
              getParamsByValue: function getParamsByValue() {}
            }),
            docHelpers.getDocField({
              key: 'userId',
              label: 'User Id',
              type: 'string'
            }),
            React.createElement(
              Button,
              { htmlType: 'submit', disabled: isSubmitting || !isValid },
              'SEND'
            )
          );
        }
      );
    };

    _this.state = {};
    return _this;
  }

  index.prototype.renderResults = function renderResults(data) {
    return data && data.data && data.data.result ? React.createElement(
      'div',
      null,
      React.createElement(
        'h2',
        null,
        'Result'
      ),
      React.createElement(JSONPretty, { id: 'json-pretty', data: data.data.result })
    ) : '';
  };

  index.prototype.render = function render() {
    var _this2 = this;

    return React.createElement(
      NetProvider,
      {
        targetKey: 'user-abilities-check',
        clearOnUnMount: true
      },
      function (_ref4) {
        var data = _ref4.data,
            error = _ref4.error,
            crudActions = _ref4.crudActions;

        return React.createElement(
          'div',
          { className: 'userAbilities__wrapper' },
          React.createElement(
            'div',
            { className: 'userAbilities__form' },
            _this2.renderForm({ crudActions: crudActions })
          ),
          React.createElement(
            'div',
            { className: 'userAbilities__results' },
            error && React.createElement(
              'div',
              null,
              error
            ),
            _this2.renderResults({ data: data })
          )
        );
      }
    );
  };

  return index;
}(Component);

export default index;
